@@ -65,6 +65,29 @@ gdl_dock_placement_get_type (void)
 }
 
 
+/* enumerations from "gdl-dock-master.h" */
+static const GEnumValue _gdl_switcher_style_values[] = {
+  { GDL_SWITCHER_STYLE_TEXT, "GDL_SWITCHER_STYLE_TEXT", "text" },
+  { GDL_SWITCHER_STYLE_ICON, "GDL_SWITCHER_STYLE_ICON", "icon" },
+  { GDL_SWITCHER_STYLE_BOTH, "GDL_SWITCHER_STYLE_BOTH", "both" },
+  { GDL_SWITCHER_STYLE_TOOLBAR, "GDL_SWITCHER_STYLE_TOOLBAR", "toolbar" },
+  { GDL_SWITCHER_STYLE_TABS, "GDL_SWITCHER_STYLE_TABS", "tabs" },
+  { GDL_SWITCHER_STYLE_NONE, "GDL_SWITCHER_STYLE_NONE", "none" },
+  { 0, NULL, NULL }
+};
+
+GType
+gdl_switcher_style_get_type (void)
+{
+  static GType type = 0;
+
+  if (!type)
+    type = g_enum_register_static ("GdlSwitcherStyle", _gdl_switcher_style_values);
+
+  return type;
+}
+
+
 /* enumerations from "gdl-dock-item.h" */
 static const GFlagsValue _gdl_dock_item_behavior_values[] = {
   { GDL_DOCK_ITEM_BEH_NORMAL, "GDL_DOCK_ITEM_BEH_NORMAL", "normal" },
@@ -135,27 +158,5 @@ gdl_dock_bar_style_get_type (void)
 }
 
 
-/* enumerations from "gdl-switcher.h" */
-static const GEnumValue _gdl_switcher_style_values[] = {
-  { GDL_SWITCHER_STYLE_TEXT, "GDL_SWITCHER_STYLE_TEXT", "text" },
-  { GDL_SWITCHER_STYLE_ICON, "GDL_SWITCHER_STYLE_ICON", "icon" },
-  { GDL_SWITCHER_STYLE_BOTH, "GDL_SWITCHER_STYLE_BOTH", "both" },
-  { GDL_SWITCHER_STYLE_TOOLBAR, "GDL_SWITCHER_STYLE_TOOLBAR", "toolbar" },
-  { GDL_SWITCHER_STYLE_TABS, "GDL_SWITCHER_STYLE_TABS", "tabs" },
-  { 0, NULL, NULL }
-};
-
-GType
-gdl_switcher_style_get_type (void)
-{
-  static GType type = 0;
-
-  if (!type)
-    type = g_enum_register_static ("GdlSwitcherStyle", _gdl_switcher_style_values);
-
-  return type;
-}
-
-
 /* Generated data ends here */
 
